==> uke-admin-web-scaffold-1.2.1.tgz: package/nav-menu/search.js <==
/* eslint-disable react/sort-comp */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { Component } from 'react';
import Mousetrap from 'mousetrap';
import { Call } from 'basic-helper';
import { ClickAway, ToolTip } from '../ui-refs';
import { Link } from '../router-multiple';
var ESC_KEY = 27;
// const Highlight = ({ children, color = 'red' }) => (
//   <strong className={`t_${color}`}>{children}</strong>
// );
var ShortcutTipDesc = function (_a) {
    var $T = _a.$T;
    return (React.createElement("div", { style: { width: 240 } },
        React.createElement("h5", null, $T('菜单搜索')),
        $T('快捷键'),
        "\uFF1Aalt + s"));
};
var SearchBox = /** @class */ (function (_super) {
    __extends(SearchBox, _super);
    function SearchBox(props) {
        var _this = _super.call(this, props) || this;
        _this.componentWillUnmount = function () {
            Mousetrap.unbind(['alt+s']);
        };
        _this.handleEsc = function (e) {
            if (e.keyCode === ESC_KEY) {
                // this._input.blur();
                _this.hide();
                if (_this.shouldBeHidden) {
                    // this.shouldBeHidden = false;
                    _this.props.onToggleNav(false);
                }
            }
        };
        _this.state = {
            searchMap: '',
            isShow: false,
        };
        return _this;
    }
    SearchBox.prototype.componentDidMount = function () {
        var _this = this;
        Mousetrap.bind(['alt+s'], function (e) {
            _this.show();
            if (!_this.props.showMenu) {
                // this.shouldBeHidden = true;
                _this.props.onToggleNav(true);
            }
            return false;
        });
    };
    SearchBox.prototype.setSearchCon = function (isShow) {
        this.setState({
            isShow: isShow,
            searchMap: isShow ? this.state.searchMap : ''
        });
    };
    SearchBox.prototype.searchMenu = function (val) {
        this.setState({
            searchMap: val
        });
    };
    SearchBox.prototype.show = function () {
        this.setSearchCon(true);
        this._input.focus();
    };
    SearchBox.prototype.hide = function () {
        this.setSearchCon(false);
    };
    SearchBox.prototype.render = function () {
        var _this = this;
        var _a = this.state, searchMap = _a.searchMap, isShow = _a.isShow;
        var _b = this.props, codeMapper = _b.codeMapper, onChangeMenu = _b.onChangeMenu;
        var allCode = Object.keys(codeMapper) || [];
        return (React.createElement(ClickAway, { onClickAway: function (e) {
                _this.hide();
                // this.shouldBeHidden = false;
            } },
            React.createElement(React.Fragment, null,
                React.createElement(ToolTip, { position: "bottom", title: (React.createElement(ShortcutTipDesc, { "$T": this.props.$T })), classNames: ['_action-btn'], className: "p10", onClick: function () { return _this.show(); }, n: "search" }),
                React.createElement("div", { className: "search-container" + (isShow ? ' show-content' : '') },
                    React.createElement("input", { ref: function (c) { _this._input = c; }, type: "text", placeholder: "\u83DC\u5355\u641C\u7D22", className: "form-control input-sm", value: searchMap, onChange: function (e) { return _this.searchMenu(e.target.value); }, 
                        // onFocus={e => this.setSearchCon(true)}
                        // onBlur={e => {
                        //   setTimeout(() => {
                        //     this.setSearchCon(false);
                        //   }, 100);
                        // }}
                        onKeyUp: this.handleEsc }),
                    React.createElement("div", { className: "hide-content" }, allCode
                        .filter(function (code) {
                        var item = codeMapper[code] || '';
                        return item.indexOf(searchMap) != -1 || code.indexOf(searchMap.toUpperCase()) != -1;
                    })
                        .map(function (code, idx) {
                        return (React.createElement(Link, { className: "result-item", key: code, to: code, onClick: function (e) {
                                Call(onChangeMenu, code);
                                _this.hide();
                            } }, codeMapper[code]));
                    }))))));
    };
    return SearchBox;
}(Component));
export default SearchBox;

==> uke-admin-web-scaffold-1.2.3.tgz: package/nav-menu/search.js <==
/* eslint-disable react/sort-comp */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { Component } from 'react';
import Mousetrap from 'mousetrap';
import { Call } from 'basic-helper';
import { ClickAway, ToolTip } from '../ui-refs';
import { Link } from '../router-multiple';
var ESC_KEY = 27;
// const Highlight = ({ children, color = 'red' }) => (
//   <strong className={`t_${color}`}>{children}</strong>
// );
var ShortcutTipDesc = function (_a) {
    var $T = _a.$T;
    return (React.createElement("div", null,
        React.createElement("div", null, $T('菜单搜索')),
        $T('快捷键'),
        "\uFF1Aalt + s"));
};
var SearchBox = /** @class */ (function (_super) {
    __extends(SearchBox, _super);
    function SearchBox(props) {
        var _this = _super.call(this, props) || this;
        _this.componentWillUnmount = function () {
            Mousetrap.unbind(['alt+s']);
        };
        _this.handleEsc = function (e) {
            if (e.keyCode === ESC_KEY) {
                // this._input.blur();
                _this.hide();
                if (_this.shouldBeHidden) {
                    // this.shouldBeHidden = false;
                    _this.props.onToggleNav(false);
                }
            }
        };
        _this.state = {
            searchMap: '',
            isShow: false,
        };
        return _this;
    }
    SearchBox.prototype.componentDidMount = function () {
        var _this = this;
        Mousetrap.bind(['alt+s'], function (e) {
            _this.show();
            if (!_this.props.showMenu) {
                // this.shouldBeHidden = true;
                _this.props.onToggleNav(true);
            }
            return false;
        });
    };
    SearchBox.prototype.setSearchCon = function (isShow) {
        this.setState({
            isShow: isShow,
            searchMap: isShow ? this.state.searchMap : ''
        });
    };
    SearchBox.prototype.searchMenu = function (val) {
        this.setState({
            searchMap: val
        });
    };
    SearchBox.prototype.show = function () {
        this.setSearchCon(true);
        this._input.focus();
    };
    SearchBox.prototype.hide = function () {
        this.setSearchCon(false);
    };
    SearchBox.prototype.render = function () {
        var _this = this;
        var _a = this.state, searchMap = _a.searchMap, isShow = _a.isShow;
        var _b = this.props, codeMapper = _b.codeMapper, onChangeMenu = _b.onChangeMenu;
        var allCode = Object.keys(codeMapper) || [];
        return (React.createElement(ClickAway, { onClickAway: function (e) {
                _this.hide();
                // this.shouldBeHidden = false;
            } },
            React.createElement(React.Fragment, null,
                React.createElement(ToolTip, { position: "top", title: (React.createElement(ShortcutTipDesc, { "$T": this.props.$T })), classNames: ['_action-btn'], className: "p10", onClick: function () { return _this.show(); }, n: "search" }),
                React.createElement("div", { className: "search-container" + (isShow ? ' show-content' : '') },
                    React.createElement("input", { ref: function (c) { _this._input = c; }, type: "text", placeholder: "\u83DC\u5355\u641C\u7D22", className: "form-control input-sm", value: searchMap, onChange: function (e) { return _this.searchMenu(e.target.value); }, 
                        // onFocus={e => this.setSearchCon(true)}
                        // onBlur={e => {
                        //   setTimeout(() => {
                        //     this.setSearchCon(false);
                        //   }, 100);
                        // }}
                        onKeyUp: this.handleEsc }),
                    React.createElement("div", { className: "hide-content" }, allCode
                        .filter(function (code) {
                        var item = codeMapper[code] || '';
                        return item.indexOf(searchMap) != -1 || code.indexOf(searchMap.toUpperCase()) != -1;
                    })
                        .map(function (code, idx) {
                        return (React.createElement(Link, { className: "result-item", key: code, to: code, onClick: function (e) {
                                Call(onChangeMenu, code);
                                _this.hide();
                            } }, codeMapper[code]));
                    }))))));
    };
    return SearchBox;
}(Component));
export default SearchBox;
